// To remove the user agent modifications when the extension is uninstalled we have to hook the uninstall method of the extensions dialog.

RegisterDNFAUninstallNotification();

// This function replaces the default functions for uninstall, confirmation and disable and replaces them with versions
// that call the original and then if the operation applied to this extension does fixes the user agent.
function RegisterDNFAUninstallNotification()
{
    var myID = "{20a82645-c095-46ed-80e3-08825760534b}";
    var uninstallConfirmed = false;

    if (gExtensionsViewController == null)
    {
        return;
    }

    // using a locally scoped function to avoid global namespace pollution
    var RemoveUserAgentModifications = function()
    {
        // Clear our user agent moficiations
        var useragentExtrasPref = Components.classes["@mozilla.org/preferences-service;1"]
                                    .getService(Components.interfaces.nsIPrefService)
                                    .getBranch("general.useragent.extra.");

        useragentExtrasPref.clearUserPref("microsoftdotnet");
    }

    // Replace the default uninstall command with our function.
    var originalUninstall = gExtensionsViewController.commands.cmd_uninstall;
    gExtensionsViewController.commands.cmd_uninstall = function (selectedItem)
    {
        originalUninstall(selectedItem);
        if (selectedItem != null)
        {
            var addonID = selectedItem.getAttribute("addonID");
            if (addonID == myID && uninstallConfirmed)
            {
                RemoveUserAgentModifications();
            }
        }
    }

    // confirmOperation is called from cmd_uninstall to confirm that the user wants to delete the extension. 
    // We need to know if they respond true or cancel the uninstall.
    var originalConfirmOperation = confirmOperation;
    confirmOperation = function (aName, aTitle, aQueryMsg, aAcceptBtn, aCancelBtn,
                      aWarnMsg, aDependantItems)
    {
        uninstallConfirmed = originalConfirmOperation(aName, aTitle, aQueryMsg, aAcceptBtn, aCancelBtn, aWarnMsg, aDependantItems);
        return uninstallConfirmed;
    }

    // Hook the disable command so we clear modifications when we're disabled.
    var originalDisable = gExtensionsViewController.commands.cmd_disable;
    gExtensionsViewController.commands.cmd_disable = function(selectedItem)
    {
        originalDisable(selectedItem);
        if (selectedItem != null)
        {
            var addonID = selectedItem.getAttribute("addonID");
            if (addonID == myID)
            {
                RemoveUserAgentModifications();
            }
        }
    }
}



