
// Check for updated .NET Framework install on browser startup
checkCLRVersionString();

function checkCLRVersionString()
{
    var useragentExtrasPref = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService)
                                .getBranch("general.useragent.extra.");

    useragentExtrasPref.QueryInterface(Components.interfaces.nsIPrefBranch2);

    // startup check the registry for the latest version of the CLR added to the IE user agent

    var addonPref = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService)
                                .getBranch("microsoft.CLR.");
    addonPref.QueryInterface(Components.interfaces.nsIPrefBranch2);
    var allAddonsInAgent = addonPref.getBoolPref("all_clr_versions_in_useragent");
    // Allow the user to configure whether they want all version of the CLR in their user agent
    // or just the highest.
    var versionString;
    if (allAddonsInAgent)
    {
        var allversions = [v.name for each (v in getInstalledCLRVersions())]
        versionString = "(" + allversions.join("; ") + ")";
    }
    else
    {
        // In the original extension we only reported the highest version of the .NET framework
        // installed on the machine.  Since this might break some applications when 4.0 comes out
        // and becomes the latest we'll perserve the 3.5 highest version as well.  "Only include the
        // latest" now indicates the latest version of each major version of the framework.
        var latestVersions = new Array();
        for (var version in getInstalledCLRVersions())
        {
            var majorVersion = version.num[0];
            if (majorVersion >= 3)
            {
                var latestVer = latestVersions[majorVersion];
                if (!latestVer ||
                    latestVer.num < version.num ||
                    (latestVer.num == version.num && 
                     latestVer.edition < version.edition)) // 'C' < 'E'
                    latestVersions[majorVersion] = version;
            }
        }

        versionString = "( " + [v.name for each (v in latestVersions)].join("; ") + ")";
    }
    useragentExtrasPref.setCharPref("microsoftdotnet", versionString);


    // For .application files on the local filesystem or UNC shares we need the browser to know the correct mime type.
    var categoryManager = Components.classes["@mozilla.org/categorymanager;1"]
                            .getService(Components.interfaces.nsICategoryManager);

    categoryManager.addCategoryEntry("ext-to-type-mapping", "application", "application/x-ms-application", true /* persist */, true /* overwrite existing */);
}

// Return [numerical version, C|E, string]
function getInstalledCLRVersions()
{
    try
    {
        var wrk = Components.classes["@mozilla.org/windows-registry-key;1"]
                            .createInstance(Components.interfaces.nsIWindowsRegKey);

        wrk.open(wrk.ROOT_KEY_LOCAL_MACHINE,
                 "SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Internet Settings\\5.0\\User Agent\\Post Platform",
                 wrk.ACCESS_READ);

        for (var i=0; i < wrk.valueCount; i++)
        {
            var name = wrk.getValueName(i);
            var matches = name.match("\\.NET (CLR|Client) (.*)");
            if (matches && matches.length > 1)
            {
                var edition = matches[1] == "CLR" ? 'E' : 'C';
                yield {num:matches[2], edition:edition, name:name};
            }
            else
            {
                matches = name.match("\\.NET(\\d\\.\\d[\\d\\.]*)(\\w)");
                if (matches && matches.length > 1)
                {
                    yield {num:matches[1], edition:matches[2], name:name};
                }
            }
        }
    }
    finally
    {
        wrk.close();
    }
}

